==> haskell-prettyprinter-ansi-terminal-1.1.1.2-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-HE8DqkC55oJIIs5QflvM5R
key: prettyprinter-ansi-terminal-1.1.1.2-HE8DqkC55oJIIs5QflvM5R
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: 57f03f08aa6c56b6b2ec7191a5096088
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-HE8DqkC55oJIIs5QflvM5R
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG
    text-1.2.3.0 prettyprinter-1.2.1-BnmCkr0fwhBDY0a61YIBKb
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             prettyprinter-1.2.1-BnmCkr0fwhBDY0a61YIBKb=5c1589311930d30a33eae3b388cc0f95
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.1.2-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-Dc2ScGNsobP7yMXUDDmK3X
key: prettyprinter-ansi-terminal-1.1.1.2-Dc2ScGNsobP7yMXUDDmK3X
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: f612d8d429d77871defb1eddf7f1c177
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-Dc2ScGNsobP7yMXUDDmK3X
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG
    text-1.2.3.0 prettyprinter-1.2.1-2ymtMxrE7kl6nFrNyDxJxV
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             prettyprinter-1.2.1-2ymtMxrE7kl6nFrNyDxJxV=6274fca4a1f17caa57a508da99a625ce
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
